/*
 * Lesen und Schreiben eines externen EEPROMs 24C02 per I2C (STM32)
 * oder des internen EEPROMS (AVR), Test
 *
 * Created: 04.02.2014
 *  Author: Nicolas
 */

#include <stdint.h>
#include <stdio.h>
#include "../src_avrcom/pgmspace.h"
#include "../src_avrcom/delay.h"
#include "../src_glcd/glcd_ks0108.h"
#include "../src_encoder/key.h"
#include "./eeprom_24Cx.h"
#include "../src_i2c/i2c_simple.h"



/* Darstellung des gesamten EEPROM-Inhalts auf dem Grafik-LCD, aehnlich
 * Memdump-Funktionen auf dem AVR */
void eeprom_test_read(void)
{
	uint8_t i, byte, status;

	I2C_init(EEPROM_I2C_DEVICE);

	printf_P(PSTR("\fRead EEPROM data\n\a"));
	glcd_setpos(128);
	for (i=0;i<EEPROM_SIZE_BYTES;i++) {
		status =  eeprom_read_byte(i,&byte);
		if(status) goto error;
		glcd_putdat(byte);
		glcd_drawnow();

		//delay_ms(1);
	}
	printf_P(PSTR("\ndone\n\a"));
	while(!key_getstroke());
	return;

	error:
	printf_P(PSTR("\nCould not connect EEPROM\n"
			"byte=%i\n"
			"error code 0x%x\n"
			"press key to leave\a"),i,status);
	while(!key_getstroke());
}


/* Darstellung des gesamten EEPROM-Inhalts auf dem Grafik-LCD, aehnlich
 * Memdump-Funktionen auf dem AVR */
void eeprom_test_write(void)
{
	uint8_t i, byte, status;

	I2C_init(EEPROM_I2C_DEVICE);
	glcd_clear();
	glcd_setpos(0);
	printf_P(PSTR("\fOverwrite EEPROM data\n\a"));
	byte = 0xAA;
	for (i=0;i<EEPROM_SIZE_BYTES;i++) {
		byte = ~byte;
		status =  eeprom_write_byte(i,byte);
		if(status) goto error;
		glcd_putdat(byte);
		glcd_drawnow();

		//delay_ms(1);
	}

	printf_P(PSTR("\ndone\n\a"));
	while(!key_getstroke());
	return;

	error:
	printf_P(PSTR("\nCould not connect EEPROM\nerror code 0x%x\n"\
			"press key to leave\a"),status);
	while(!key_getstroke());
}


/* Darstellung des gesamten EEPROM-Inhalts auf dem Grafik-LCD, aehnlich
 * Memdump-Funktionen auf dem AVR, blockweise auslesen */
void eeprom_test_read_block(void)
{
	uint_fast8_t i, status;
	uint8_t buffer[EEPROM_SIZE_BYTES];

	printf_P(PSTR("\fRead EEPROM data\n\a"));

	I2C_init(EEPROM_I2C_DEVICE); // initialize I2C peripheral

	status =  eeprom_read_block(buffer,0,3);
	status =  eeprom_read_block(buffer,0,EEPROM_SIZE_BYTES);

	if(status) goto error;

	for (i=0;i<EEPROM_SIZE_BYTES;i++) {
		glcd_putdat(buffer[i]);
		glcd_drawnow();
	}
	printf_P(PSTR("\ndone\n\a"));
	while(!key_getstroke());
	return;

	error:
	printf_P(PSTR("\nCould not connect EEPROM\nerror code 0x%x\n"\
			"press key to leave\a"),status);
	while(!key_getstroke());
}


/* Testen: Blockweise in EEPROM schreiben */
void eeprom_test_write_block(void)
{
	uint8_t i, status;
	uint8_t buffer[EEPROM_SIZE_BYTES];
	for (i=0;i<EEPROM_SIZE_BYTES;i++) buffer[i] = i;

	glcd_clear();
	glcd_setpos(0);
	printf_P(PSTR("\fWrite EEPROM data block\n\a"));

	I2C_init(EEPROM_I2C_DEVICE); // initialize I2C peripheral
	status =  eeprom_write_block(buffer,0,EEPROM_SIZE_BYTES);
	if(status) goto error;

	printf_P(PSTR("\ndone\n\a"));
	while(!key_getstroke());
	return;

	error:
	printf_P(PSTR("\nCould not connect EEPROM\nerror code 0x%x\n"\
			"press key to leave\a"),status);
	while(!key_getstroke());
}

